guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

340/376: Rename function


From: Ludovic Courtès
Subject: 340/376: Rename function
Date: Wed, 28 Jan 2015 22:06:02 +0000

civodul pushed a commit to tag 1.8
in repository guix.

commit b5ed5b6e666e9d1e23b7cbc815684bfef52c3d41
Author: Eelco Dolstra <address@hidden>
Date:   Wed Dec 10 17:25:12 2014 +0100

    Rename function
---
 src/libstore/build.cc |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/libstore/build.cc b/src/libstore/build.cc
index 539d0b2..ab8923b 100644
--- a/src/libstore/build.cc
+++ b/src/libstore/build.cc
@@ -816,8 +816,8 @@ private:
     /* Start building a derivation. */
     void startBuilder();
 
-    /* Initialise the builder's process. */
-    void initChild();
+    /* Run the builder's process. */
+    void runChild();
 
     friend int childEntry(void *);
 
@@ -1915,7 +1915,7 @@ void DerivationGoal::startBuilder()
 
     /* Fork a child to build the package. */
     pid = startProcess([&]() {
-        initChild();
+        runChild();
     });
 
     /* parent */
@@ -1936,7 +1936,7 @@ void DerivationGoal::startBuilder()
 }
 
 
-void DerivationGoal::initChild()
+void DerivationGoal::runChild()
 {
     /* Warning: in the child we should absolutely not make any SQLite
        calls! */



reply via email to

[Prev in Thread] Current Thread [Next in Thread]